@@ -3,7 +3,7 @@ Basic functions for getting data from a dWeather gateway via https.
 """
 import os, pickle, math, requests, datetime, io, gzip, json, logging, csv
 from dweather_client.ipfs_errors import *
-from dweather_client.utils import listify_period, lat_lon_to_rtma_grid, find_closest_lat_lon, build_rtma_reverse_lookup, build_rtma_lookup, conventional_lat_lon_to_cpc, cpc_lat_lon_to_conventional, celcius_to_fahrenheit
+from dweather_client.utils import listify_period, lat_lon_to_rtma_grid, find_closest_lat_lon, build_rtma_reverse_lookup, build_rtma_lookup, conventional_lat_lon_to_cpc, cpc_lat_lon_to_conventional, mms_to_inches, celcius_to_fahrenheit
 import dweather_client.ipfs_datasets
 from collections import Counter, deque
 
@@ -75,7 +75,6 @@ def traverse_ll(head):
         else:
             return release_ll
 
-
 def get_hurricane_release_dict(release_hash, url=GATEWAY_URL):
     url = "%s/ipfs/%s/history.json.gz" % (url, release_hash)
     resp = requests.get(url)
@@ -102,28 +101,59 @@ def get_hurricane_dict(head=get_heads()['atcf_btk-seasonal']):
     for release_hash in release_ll:
         release_content = get_hurricane_release_dict(release_hash)
         try:
-            hurr_dict['features'].append(release_content['features'])
+            hurr_dict['features'] += release_content['features']
         except KeyError:
             hurr_dict.update(release_content)
     return hurr_dict
 
+def get_simulated_hurricane_files(basin):
+    """
+    Gets the names of files containing STORM simulated TC data. Takes a basin ID, one of:
+    EP, NA, NI, SI, SP or WP
+    """
+    if basin not in {'EP', 'NA', 'NI', 'SI', 'SP', 'WP'}:
+        raise ValueError("Invalid basin ID")
+    heads = get_heads()
+    hurr_hash = heads['storm-simulated-hurricane']
+    metadata  = get_metadata(hurr_hash)
+    base_url = f"{GATEWAY_URL}/ipfs/{hurr_hash}/"
+    files = [base_url + f for f in metadata['files'] if basin in f]
+    return files
 
-def get_station_csv(station_id, url=GATEWAY_URL):
+
+def get_station_csv(station_id, station_dataset="ghcnd-imputed-daily", url=GATEWAY_URL):
     """
     Retrieve the contents of a station data csv file.
     Args:
         station_id (str): the id of the weather station
+        station_dataset (str): which dataset to use, on of ["ghcnd", "ghcnd-imputed-daily"]
     returns:
         the contents of the station csv file as a string
     """
     all_hashes = get_heads()
-    dataset_hash = all_hashes["ghcnd"]
+    dataset_hash = all_hashes[station_dataset]
     dataset_url = "%s/ipfs/%s/%s.csv.gz" % (url, dataset_hash, str(station_id))
     r = requests.get(dataset_url)
     r.raise_for_status()
     with gzip.GzipFile(fileobj=io.BytesIO(r.content)) as zip_data:
         return zip_data.read().decode("utf-8")
 
+
+def parse_station_snowfall_as_dict(csv_text, use_inches=True):
+    reader = csv.reader(csv_text.split())
+    column_names = next(reader)
+    date_col = column_names.index('DATE')
+    snow_col = column_names.index('SNOW')
+    snowfall = {}
+    for row in reader:
+        if row[snow_col] == '':
+            continue
+        row_snow = float(row[snow_col])/10.0
+        if use_inches:
+            row_snow = mms_to_inches(row_snow)
+        snowfall[datetime.datetime.strptime(row[date_col], "%Y-%m-%d").date()] = row_snow
+
+
 def parse_station_temps_as_dict(csv_text, use_fahrenheit=True):
     """
     Parse a station CSV file and get column values
@@ -136,7 +166,6 @@ def parse_station_temps_as_dict(csv_text, use_fahrenheit=True):
             dict of datetime.date: float temperature highs
             dict of datetime.date: float temperature lows
     """
-    #csv_text = get_station_csv(station_id)
     reader = csv.reader(csv_text.split())
     column_names = next(reader)
     date_col = column_names.index('DATE')
@@ -297,7 +326,7 @@ def get_rainfall_dict(lat, lon, dataset_revision, return_metadata=False, get_cou
     rainfall_dict = Counter({}) if get_counter else {}
     for i in range(days_in_record):
         if day_strs[i] == metadata["missing value"]:
-            rainfall_dict[dataset_start_date + datetime.timedelta(days=i)] = None
+            rainfall_dict[dataset_start_date + datetime.timedelta(days=i)] = 0 if get_counter else None
         else:
             rainfall_dict[dataset_start_date + datetime.timedelta(days=i)] = float(day_strs[i])
     if return_metadata:
